class puppet_enterprise::amq::certs(
  $brokername          = $::clientcert,
  $keystore_password   = $puppet_enterprise::params::activemq_java_ks_password,
  $truststore_password = $puppet_enterprise::params::activemq_java_ts_password,
) inherits puppet_enterprise::params {

  Pe_java_ks {
    path   => [ '/opt/puppet/bin', '/usr/bin', '/bin', '/usr/sbin', '/sbin' ],
    notify => Class['puppet_enterprise::amq::service'],
  }

  $java_ks_path = '/etc/puppetlabs/activemq/broker.ks'
  $java_ts_path = '/etc/puppetlabs/activemq/broker.ts'

  pe_java_ks { 'puppetca:truststore':
    ensure       => latest,
    target       => $java_ts_path,
    certificate  => $puppet_enterprise::params::localcacert,
    password     => $truststore_password,
    trustcacerts => true,
    require      => Package['pe-activemq'],
  }

  pe_java_ks { "${brokername}:keystore":
    ensure      => latest,
    target      => $java_ks_path,
    certificate => "${puppet_enterprise::params::ssl_dir}/certs/${::clientcert}.pem",
    private_key => "${puppet_enterprise::params::ssl_dir}/private_keys/${::clientcert}.pem",
    password    => $keystore_password,
    require     => Pe_java_ks['puppetca:truststore'],
  }

  file { [$java_ts_path, $java_ks_path]:
    ensure  => file,
    owner   => $puppet_enterprise::params::root_user,
    group   => 'pe-activemq',
    mode    => '0640',
    require => Pe_java_ks['puppetca:truststore', "${brokername}:keystore"],
  }
}
